# <img alt="amset" src="https://raw.githubusercontent.com/hackingmaterials/amset/master/docs/src/amset_logo.png" width="250">

AMSET is a package for calculating electronic transport properties from
first-principles calculations.

- **Website (including documentation):** https://hackingmaterials.lbl.gov/amset/
- **Help/Support:** https://discuss.matsci.org/c/amset
- **Source:** https://github.com/hackingmaterials/amset

A paper with the full technical details of AMSET will be published soon.

Interested in contributing? See our [contribution guidelines](https://github.com/hackingmaterials/amset/blob/master/CONTRIBUTING.md)
